@@ -17,7 +17,7 @@
 #include "../Common/FileIO.hpp"
 #include "./abfutil.h"
 
-#if defined(__linux__) || defined(__STF__) || defined(__APPLE__) || defined(__MINGW32__)
+#if !defined(_WINDOWS) || defined(__MINGW32__) || defined(__STF__)
 	#define max(a,b)   (((a) > (b)) ? (a) : (b))
 	#define min(a,b)   (((a) < (b)) ? (a) : (b))
 #endif
