@@ -121,8 +121,9 @@ stfio::filetype stfio::importBiosigFile(const std::string &fName, Recording &Ret
         destructHDR(hdr);
         return type;
     }
-    if (biosig_get_filetype(hdr)==ATF) {
-        // ATF support should be handled by importATF not importBiosig
+    enum FileFormat biosig_filetype=biosig_get_filetype(hdr);
+    if (biosig_filetype==ATF || biosig_filetype==ABF2) {
+        // ATF and ABF2 support should be handled by importATF, and importABF not importBiosig
         ReturnData.resize(0);
         destructHDR(hdr);
         return type;
@@ -270,8 +271,12 @@ stfio::filetype stfio::importBiosigFile(const std::string &fName, Recording &Ret
     Desc += std::string ("\nUser specified Annotations:\n")+annotationTableDesc;
 
     ReturnData.SetFileDescription(Desc);
-    // hdr->AS.bci2000 is an alias to hdr->AS.fpulse, which available only in libbiosig v1.6.0 and later
-    if (hdr->AS.bci2000) ReturnData.SetGlobalSectionDescription(hdr->AS.bci2000 + '\0');
+
+#if (BIOSIG_VERSION > 10509)
+    tmpstr = biosig_get_application_specific_information(hdr);
+    if (tmpstr != NULL) /* MSVC2008 can not properly handle std::string( (char*)NULL ) */
+        ReturnData.SetGlobalSectionDescription(tmpstr);
+#endif
 
     ReturnData.SetXScale(1000.0/biosig_get_samplerate(hdr));
     ReturnData.SetXUnits("ms");
@@ -305,6 +310,12 @@ stfio::filetype stfio::importBiosigFile(const std::string &fName, Recording &Ret
            This causes problems with the ABF fallback mechanism
         */
 #else
+    if ( hdr->TYPE==ABF2 ) {
+        // ABF2 support should be handled by importABF not importBiosig
+        ReturnData.resize(0);
+        destructHDR(hdr);
+        return type;
+    }
     if (hdr->TYPE==ABF && hdr->AS.B4C_ERRNUM) {
         /* this triggers the fall back mechanims w/o reporting an error message */
 #endif
@@ -499,7 +510,8 @@ stfio::filetype stfio::importBiosigFile(const std::string &fName, Recording &Ret
     }
     ReturnData.SetFileDescription(Desc);
     // hdr->AS.bci2000 is an alias to hdr->AS.fpulse, which available only in libbiosig v1.6.0 or later
-    if (hdr->AS.bci2000) ReturnData.SetGlobalSectionDescription(hdr->AS.bci2000 + '\0');
+
+    if (hdr->AS.bci2000) ReturnData.SetGlobalSectionDescription(std::string(hdr->AS.bci2000));
 
     ReturnData.SetXScale(1000.0/hdr->SampleRate);
     ReturnData.SetXUnits("ms");
