@@ -139,7 +139,7 @@ enum {
     ID_NEWFROMSELECTED,
     ID_NEWFROMSELECTEDTHIS,
     ID_NEWFROMALL,
-    ID_CONCATENATE,
+    ID_CONCATENATE_MULTICHANNEL,
     ID_SUBTRACTBASE,
     ID_FILTER,
     ID_POVERN,
